{% load i18n future shop_tags mezzanine_tags %}
<div class="panel">
    {% spaceless %}
    <a href="{% url "shop_cart" %}">
    {% blocktrans count request.cart.total_quantity as cart_quantity %}1 item{% plural %}{{ cart_quantity }} items{% endblocktrans %}
    {% trans "in cart" %}:
    {{ request.cart.total_price|currency }}</a><br>
    {% if request.cart.total_quantity != 0 %}
    <a href="{% url "shop_checkout" %}" class="btn btn-primary">
        {% if request.session.order.step %}{% trans "Return to Checkout" %}{% else %}{% trans "Go to Checkout" %}{% endif %}
    </a><br>
    {% endif %}
    <a href="{% url "shop_wishlist" %}" class="btn-wishlist">
    {% blocktrans count request.wishlist|length as wishlist_count %}Wishlist contains 1 item{% plural %} Wishlist contains {{ wishlist_count }} items{% endblocktrans %}</a>
    {% ifinstalled mezzanine.accounts %}
    <br>
    {% include "accounts/includes/user_panel.html" %}
    {% endifinstalled %}
    {% endspaceless %}
</div>
