{% extends "shop/checkout.html" %}
{% load i18n mezzanine_tags %}

{% block fields %}
{% if request.cart.has_items %}
{% include "shop/includes/payment_fields.html" %}
{% fields_for form.other_fields %}
{% endif %}
{% endblock %}
