
/* Categories and products */
.btn-wishlist {line-height:30px;}
.product-sorting {margin:20px 0 25px 0;}
.product-sorting label {display:inline;}
.product-sorting select {margin:0 0 0 5px;}
#category .thumbnails h6 {color:#777; height:50px; margin:10px 0 5px 0; border-bottom:1px dashed #ddd;}
#category .thumbnails a {width:100px; height:200px; color:#666; padding:20px;}
#category .categories.thumbnails h6 {border-bottom:0px;}
#category .categories.thumbnails a {width:100px; height:140px; color:#666; padding:20px;}
#category .thumbnails a:hover {text-decoration:none;}
#category .thumbnails .placeholder {width:100px; height:100px; background:rgba(220,220,220, 0.1);}
#related-products.thumbnails h6 {color:#777; height:40px; margin:10px 0 5px 0; border-bottom:1px dashed #ddd;}
#related-products.thumbnails a {width:90px; height:170px; color:#666; padding:12px;}
#related-products.thumbnails a:hover {text-decoration:none;}
#related-products.thumbnails li {margin-right:-14px;}
.old-price {text-decoration:line-through; display:block; color:#ccc; margin-bottom:3px;}
#product-images-thumb li {display:inline; margin-right:-10px;}
.product-image-full {background:#fff; padding:20px;}
.right .btn-primary {margin:5px 0;}


/* Form actions (put primary button on right) */
.form-shop .form-actions {width:100%; padding-left:0; padding-right:0; margin:40px 0 !important;}
.form-shop .form-actions-wrap {float:left; margin-left:160px;}
.form-shop .form-actions-wrap * {float:right; margin-right:15px;}

/* Cart and order history */
.order-history th, .form-cart th {white-space:nowrap; text-align:right;}
.order-history th, .form-cart td {text-align:right; vertical-align:middle;}
.order-history .left, .form-cart .left {text-align:left;}
.order-history .center, .form-cart .center, .form-cart .quantity {text-align:center;}
.form-cart .quantity input {width:25px; text-align:center; margin:0;}
.form-cart label {margin-right:10px; font-weight:bold;}
.order-history .right, .form-cart .form-actions {text-align:right;}
.form-cart .form-actions-wrap {float:right; margin-right:5px;}
.order-history .btn {float:right; margin:0 0 0 5px;}
.btn-order-history {float:right; margin:-75px 20px 0 0;}
.discount-form {float:right;}
.discount-form .btn {float:right; margin:-5px 7px 0 0;}

/* Wishlist */
.wishlist img {vertical-align:middle; margin-right:5px;}
.wishlist form {margin:0; float:right;}
.wishlist .btn {margin-left:5px;}
.wishlist .btn-primary {margin-left:20px;}

/* Cart panel in checkout */
#checkout .checkout-panel {float:right; margin:0px 30px 0 0;}
#checkout .checkout-panel li {border-bottom:1px dashed #eee; padding:10px 0; color:#999; line-height:15px;}
#checkout .checkout-panel img {float:left; margin-right:10px;}
#checkout .checkout-panel .price {float:right; line-height:20px;}
#checkout .checkout-panel .btn {float:right; margin-top:15px;}
#checkout .checkout-panel .order-totals {text-align:right;}
.order-totals label {margin-right:10px; display:inline;}
.order-totals {float:right; margin:10px 0;}


/* Checkout forms */
#checkout .left, #checkout .right {display:none !important;}
#checkout .middle {width:100%;}
#checkout-form {margin-left:5px;}
#checkout-form .non-field-errors:after {display:none;}
#checkout-form .form-actions {width:100%; padding-left:0; padding-right:0; margin:40px 0 !important;}
#checkout-form .form-actions-wrap {float:left; margin-left:170px;}
#checkout-form .form-actions input {float:right;}
#checkout-form legend {text-indent:170px;}
#checkout-form label {padding:4px 15px;}
#checkout-form fieldset {background:rgba(220,220,220, 0.1); padding-bottom:10px; margin-bottom:20px;}
#checkout-form .control-group input, #checkout-form textarea {width:60%;}
#id_card_ccv {width:50px !important;}


/* Checkout checkboxes (right aligned labels) */
.input_id_same_billing_shipping .controls, .input_id_remember .controls {float:left; margin-left:170px;}
.input_id_same_billing_shipping input, .input_id_remember input {width:auto !important;}
.input_id_same_billing_shipping label, .input_id_remember label {width:auto !important;
    float:none !important; margin:0 0 -24px 175px; text-align:left !important; font-weight:normal;}


/* Checkout expiry fields (mmake two fields look like one) */
.card-expiry-fields select {width:auto;}
.card-expiry-fields .control-group label {display:none;}
.card-expiry-fields .control-group, .card-expiry-fields .controls {display:inline; margin:0;}
.card-expiry-fields .control-group:before, .card-expiry-fields .control-group:after {display:none;}


/* Checkout confirmation */
.confirmation {width:40% !important; float:left; margin-right:20px;}
.confirmation legend {text-indent:50px !important;}
.confirmation ul {margin:20px;}
.confirmation li {margin:5px 0; color:#999;}
.confirmation label {display:inline; padding-right:5px; width:170px;}
