{% load shop_tags i18n %}

<p align="right">,{% trans "Dear" %} {{ order.billing_detail_first_name }}</p>
<p align="right">{% trans "Your order has been successful, details are below." %}</p>
{% include "shop/includes/order_details_rtl.html" %}

