{% extends "shop/checkout.html" %}
{% load i18n shop_tags %}

{% block fields %}
{% if request.cart.has_items %}

<fieldset class="confirmation">
	<legend>{% trans "Billing Details" %}</legend>
    <ul class="unstyled">
	    {% for field, value in form.billing_detail_fields.values %}
        <li><label>{{ field }}:</label> {{ value }}</li>
	    {% endfor %}
	</ul>
</fieldset>

<fieldset class="confirmation">
	<legend>{% trans "Shipping Details" %}</legend>
	<ul class="unstyled">
	    {% for field, value in form.shipping_detail_fields.values %}
        <li><label>{{ field }}:</label> {{ value }}</li>
	    {% endfor %}
	    {% for field, value in form.additional_instructions_field.values %}
        <li><label>{{ field }}:</label> {{ value }}</li>
	    {% endfor %}
	</ul>
</fieldset>
{% if settings.SHOP_PAYMENT_STEP_ENABLED %}
{% comment %}
<br style="clear:both;">
<fieldset class="confirmation">
	<legend>{% trans "Payment Details" %}</legend>
	<ul class="unstyled">
	    {% for field, value in form.card_name_field.values %}
        <li><label>{{ field }}:</label> {{ value }}</li>
        {% endfor %}
	    {% for field, value in form.card_type_field.values %}
        <li><label>{{ field }}:</label> {{ value }}</li>
        {% endfor %}
        <li>
    	    {% with form.card_expiry_fields.values as expiry_fields %}
    	        {% with expiry_fields.next as month_field %}
    	        <label>{{ month_field.0 }}:</label> {{ month_field.1 }}/{{ expiry_fields.next.1 }}
    	        {% endwith %}
            {% endwith %}
        </li>
	    {% for field, value in form.card_fields.values %}
        <li><label>{{ field }}:</label> {{ value }}</li>
        {% endfor %}
	</ul>
</fieldset>
{% endcomment %}
{% endif %}
<br style="clear:both;">

{% for field in form %}{{ field }}{% endfor %}

{% endif %}
{% endblock %}
